=========================================================
Configuration options for the Application Catalog service
=========================================================

The following options can be set in the ``/etc/murano/murano.conf`` config file.

.. only:: html

   A :doc:`sample configuration file <sample_config>` is also available.

.. show-options::
   :config-file: etc/oslo-config-generator/murano.conf
